@@ -21,7 +21,6 @@ import tempfile
 import traceback
 import zipfile
 import pkg_resources
-
 from concurrent.futures.thread import ThreadPoolExecutor
 from io import BytesIO, StringIO
 
@@ -30,23 +29,23 @@ logging.basicConfig(level=logging.INFO,
 
 import dacite
 import pandas as pd
-
 from flask import Flask, jsonify, request, send_file, make_response, send_from_directory, current_app, Blueprint
 from flask_cors import CORS, cross_origin
 
+from label_sleuth.orchestrator.background_jobs_manager import BackgroundJobsManager
+from label_sleuth.training_set_selector.training_set_selector_factory import TrainingSetSelectionFactory
 from label_sleuth.app_utils import elements_back_to_front, extract_iteration_information_list, \
     extract_enriched_ngrams_and_weights_list, get_element, get_natural_sort_key, validate_category_id, \
     validate_workspace_id
 from label_sleuth.authentication import authenticate_response, login_if_required, verify_password
 from label_sleuth.active_learning.core.active_learning_factory import ActiveLearningFactory
 from label_sleuth.config import Configuration
-from label_sleuth.models.core.tools import SentenceEmbeddingService
 from label_sleuth.configurations.users import User
 from label_sleuth.data_access.core.data_structs import LABEL_POSITIVE, LABEL_NEGATIVE, Label
 from label_sleuth.data_access.data_access_api import AlreadyExistsException
 from label_sleuth.data_access.file_based.file_based_data_access import FileBasedDataAccess
-from label_sleuth.models.core.models_background_jobs_manager import ModelsBackgroundJobsManager
 from label_sleuth.models.core.models_factory import ModelFactory
+from label_sleuth.models.core.tools import SentenceEmbeddingService
 from label_sleuth.orchestrator.core.state_api.orchestrator_state_api import IterationStatus, OrchestratorStateApi
 from label_sleuth.orchestrator.orchestrator_api import OrchestratorApi
 
@@ -79,13 +78,21 @@ def create_app(config: Configuration, output_dir) -> LabelSleuthApp:
     app.users = {x['username']: dacite.from_dict(data_class=User, data=x) for x in app.config["CONFIGURATION"].users}
     app.tokens = [user.token for user in app.users.values()]
     sentence_embedding_service = SentenceEmbeddingService(embedding_model_dir=output_dir,
-                                                          preload_spacy_model_name=config.language.spacy_model_name)
+                                                          preload_spacy_model_name=config.language.spacy_model_name,
+                                                          preload_fasttext_language_id=
+                                                          config.language.fasttext_language_id)
+    data_access = FileBasedDataAccess(output_dir)
+    background_jobs_manager = BackgroundJobsManager()
+    training_set_selection_factory = TrainingSetSelectionFactory(data_access, background_jobs_manager)
+
     app.orchestrator_api = OrchestratorApi(OrchestratorStateApi(os.path.join(output_dir, "workspaces")),
-                                           FileBasedDataAccess(output_dir),
+                                           data_access,
                                            ActiveLearningFactory(),
                                            ModelFactory(os.path.join(output_dir, "models"),
-                                                        ModelsBackgroundJobsManager(),
+                                                        background_jobs_manager,
                                                         sentence_embedding_service),
+                                           training_set_selection_factory,
+                                           background_jobs_manager,
                                            sentence_embedding_service,
                                            app.config["CONFIGURATION"])
     app.register_blueprint(main_blueprint)
@@ -118,7 +125,7 @@ def login():
     password = post_data["password"]
 
     if not verify_password(username, password):
-        logging.warning(f"LOGIN FAILED: {username} {password}")
+        logging.warning(f"Login failed for username {username}")
         return make_response(jsonify({
             'error': "Login failed: wrong username or password"
         }), 401)
@@ -1201,7 +1208,8 @@ def get_feature_flags():
     res =  {
         "login_required": curr_app.config['CONFIGURATION'].login_required,
         "main_panel_elements_per_page": curr_app.config['CONFIGURATION'].main_panel_elements_per_page,
-        "sidebar_panel_elements_per_page": curr_app.config['CONFIGURATION'].sidebar_panel_elements_per_page
+        "sidebar_panel_elements_per_page": curr_app.config['CONFIGURATION'].sidebar_panel_elements_per_page,
+        "right_to_left": curr_app.config['CONFIGURATION'].language.right_to_left
     }
     logging.debug(f'Feature flags are: {res}')
     return jsonify(res) 
