@@ -17,16 +17,20 @@ import json
 import logging
 
 from dataclasses import dataclass, field
-from typing import List
+from typing import List, Type
 
 import dacite
 
 from label_sleuth.active_learning.core.active_learning_api import ActiveLearningStrategy
+from label_sleuth.active_learning.core.active_learning_policies import ActiveLearningPolicies
 from label_sleuth.active_learning.core.catalog import ActiveLearningCatalog
+from label_sleuth.active_learning.policy.active_learning_policy import ActiveLearningPolicy
 from label_sleuth.models.core.languages import Language, Languages
 from label_sleuth.models.core.model_policies import ModelPolicies
 from label_sleuth.models.policy.model_policy import ModelPolicy
-from label_sleuth.training_set_selector.train_set_selector_api import TrainingSetSelectionStrategy
+from label_sleuth.training_set_selector.train_set_selector_api import TrainSetSelectorAPI
+from label_sleuth.training_set_selector.train_set_selectors import TrainSetSelectorAllLabeled
+from label_sleuth.training_set_selector.train_set_selectors_catalog import TrainSetSelectorsCatalog
 
 
 @dataclass
@@ -34,12 +38,13 @@ class Configuration:
     first_model_positive_threshold: int
     changed_element_threshold: int
     model_policy: ModelPolicy
-    training_set_selection_strategy: TrainingSetSelectionStrategy
-    active_learning_strategy: ActiveLearningStrategy
+    training_set_selection_strategy: Type[TrainSetSelectorAPI]
     precision_evaluation_size: int
     apply_labels_to_duplicate_texts: bool
     language: Language
     login_required: bool
+    active_learning_strategy: ActiveLearningStrategy = None
+    active_learning_policy: ActiveLearningPolicy = None
     main_panel_elements_per_page: int = 500
     sidebar_panel_elements_per_page: int = 50
     users: List[dict] = field(default_factory=list)
@@ -47,8 +52,9 @@ class Configuration:
 
 converters = {
     ModelPolicy: lambda x: getattr(ModelPolicies, x),
-    TrainingSetSelectionStrategy: lambda x: getattr(TrainingSetSelectionStrategy, x),
+    Type[TrainSetSelectorAPI]: lambda x: getattr(TrainSetSelectorsCatalog, x),
     ActiveLearningStrategy: lambda x: getattr(ActiveLearningCatalog, x),
+    ActiveLearningPolicy: lambda x: getattr(ActiveLearningPolicies, x),
     Language: lambda x: getattr(Languages, x)
 }
 
@@ -69,4 +75,10 @@ def load_config(config_path, command_line_args=None) -> Configuration:
         data_class=Configuration, data=raw_cfg,
         config=dacite.Config(type_hooks=converters),
     )
+    if config.active_learning_strategy is None and config.active_learning_policy is None:
+        raise Exception("Either active_learning_strategy or active_learning_policy must be specified")
+
+    if config.active_learning_strategy is not None and config.active_learning_policy is not None:
+        raise Exception("Only one of active_learning_strategy or active_learning_policy can be specified")
+
     return config
