@@ -82,7 +82,8 @@ def filter_by_query_and_document_uri(df: pd.DataFrame, query, is_regex: bool = F
     if document_id is not None:
         df = df[df.uri.str.startswith(f"{document_id}-")]
     if query:
-        df = df[df.text.str.contains(query, case=False, na=False, regex=is_regex)]
+        # case=is_regex: we want the query to be case sensitive if we are matching using a regex and case insensitive otherwise
+        df = df[df.text.str.contains(query, case=is_regex, na=False, regex=is_regex)]
     return df
 
 
