@@ -18,7 +18,8 @@ import torch
 INFER_CACHE_SIZE = 10000000
 ACTIVE_LEARNING_SUGGESTION_COUNT = 1000
 CPU_WORKERS = 10  # TODO use number of cores?
-GPU_AVAILABLE = torch.cuda.is_available()
+MPS_GPU_AVAILABLE = torch.backends.mps.is_available()  # relevant for mac machines with GPU devices (e.g., Apple M1 chip)
+GPU_AVAILABLE = torch.cuda.is_available() or MPS_GPU_AVAILABLE
 GPU_WORKERS = 1  # Currently only one GPU is supported
 
 
