@@ -22,11 +22,11 @@ from transformers import AutoModelForSequenceClassification, AutoTokenizer, Inpu
     TextClassificationPipeline, PreTrainedModel
 from transformers.pipelines.pt_utils import KeyDataset
 
-from label_sleuth.models.core.languages import Language
-from label_sleuth.models.core.models_background_jobs_manager import ModelsBackgroundJobsManager
-from label_sleuth.definitions import GPU_AVAILABLE
+from label_sleuth.models.core.languages import Language, Languages
+from label_sleuth.definitions import GPU_AVAILABLE, MPS_GPU_AVAILABLE
 from label_sleuth.models.core.model_api import ModelAPI
 from label_sleuth.models.core.prediction import Prediction
+from label_sleuth.orchestrator.background_jobs_manager import BackgroundJobsManager
 
 
 @dataclass
@@ -35,22 +35,22 @@ class TransformerComponents:
     language: Language
 
 
-class HFTransformers(ModelAPI):
+class HFTransformerModel(ModelAPI):
     """
     Basic implementation for a pytorch-based transformer model that relies on the huggingface transformers library.
     """
-    def __init__(self, output_dir, models_background_jobs_manager: ModelsBackgroundJobsManager,
-                 pretrained_model="bert-base-uncased", batch_size=32, learning_rate=5e-5, num_train_epochs=5):
+    def __init__(self, output_dir, background_jobs_manager: BackgroundJobsManager,
+                 pretrained_model, batch_size=32, learning_rate=5e-5, num_train_epochs=5):
         """
         :param output_dir:
-        :param models_background_jobs_manager:
+        :param background_jobs_manager:
         :param pretrained_model: the name of a transfomer model from huggingface.co, or a path to a directory containing
         a pytorch model created using the huggingface transformers library
         :param batch_size:
         :param learning_rate:
         :param num_train_epochs:
         """
-        super().__init__(output_dir, models_background_jobs_manager, gpu_support=True)
+        super().__init__(output_dir, background_jobs_manager, gpu_support=True)
         self.pretrained_model_name = pretrained_model
         self.batch_size = batch_size
         self.learning_rate = learning_rate
@@ -66,7 +66,8 @@ class HFTransformers(ModelAPI):
                                           overwrite_output_dir=True,
                                           num_train_epochs=self.num_train_epochs,
                                           per_device_train_batch_size=self.batch_size,
-                                          learning_rate=self.learning_rate)
+                                          learning_rate=self.learning_rate,
+                                          use_mps_device=MPS_GPU_AVAILABLE)
         model = AutoModelForSequenceClassification.from_pretrained(self.pretrained_model_name)
         trainer = Trainer(model=model, args=training_args, train_dataset=train_dataset)
         trainer.train()
@@ -78,10 +79,20 @@ class HFTransformers(ModelAPI):
         return TransformerComponents(model=model, language=language)
 
     def infer(self, model_components: TransformerComponents, items_to_infer):
-        device = 0 if GPU_AVAILABLE else -1
+        if GPU_AVAILABLE:
+            if MPS_GPU_AVAILABLE:
+                device = 'mps'
+            else:
+                device = 'cuda:0'
+        else:
+            device = 'cpu'
+
         pipeline = TextClassificationPipeline(model=model_components.model, tokenizer=self.tokenizer, device=device)
 
-        ds = Dataset.from_dict({'text': [item['text'] for item in items_to_infer]})
+        # we sort examples by length to optimize inference time
+        sorted_items_to_infer = sorted(enumerate(items_to_infer), key=lambda x: len(x[1]['text']))
+        orig_idx_to_new_idx = {orig_idx: new_idx for new_idx, (orig_idx, _) in enumerate(sorted_items_to_infer)}
+        ds = Dataset.from_dict({'text': [item['text'] for _, item in sorted_items_to_infer]})
         predictions = []
         for output in tqdm(pipeline(KeyDataset(ds, 'text'), batch_size=self.batch_size, truncation=True),
                            total=len(items_to_infer), desc="classification inference"):
@@ -89,9 +100,11 @@ class HFTransformers(ModelAPI):
             score = output['score'] if label is True else 1-output['score']
 
             predictions.append(Prediction(label=label, score=score))
+
+        predictions = [predictions[orig_idx_to_new_idx[i]] for i in range(len(predictions))]
         return predictions
 
-    def get_model_dir_name(self): # for backward compatibility, we override the default get_model_dir_name()
+    def get_model_dir_name(self):  # for backward compatibility, we override the default get_model_dir_name()
         return "transformers"
 
     def process_train_inputs(self, texts, labels) -> List[InputFeatures]:
@@ -108,8 +121,44 @@ class HFTransformers(ModelAPI):
             inputs = (self.tokenizer.encode_plus(text, add_special_tokens=True, max_length=self.max_seq_length,
                                                  pad_to_max_length=True))
 
-            features.append(InputFeatures(input_ids=inputs['input_ids'],
-                                          attention_mask=inputs['attention_mask'],
-                                          token_type_ids=inputs['token_type_ids'],
+            features.append(InputFeatures(**inputs,
                                           label=label))
         return features
+
+
+class HFBert(HFTransformerModel):
+    """
+    Implementation of a classifier using the BERT (Devlin et al., 2018) base model
+    https://huggingface.co/bert-base-uncased
+    """
+    def __init__(self, output_dir, background_jobs_manager: BackgroundJobsManager):
+        super().__init__(output_dir, background_jobs_manager,
+                         pretrained_model="bert-base-uncased",
+                         batch_size=32, learning_rate=5e-5, num_train_epochs=5)
+
+    def get_supported_languages(self):
+        return {Languages.ENGLISH}
+
+
+class HFXLMRoberta(HFTransformerModel):
+    """
+    Implementation of a classifier using the multilingual XLM-R (Conneau et al., 2019) base model
+    https://huggingface.co/xlm-roberta-base
+    """
+    def __init__(self, output_dir, background_jobs_manager: BackgroundJobsManager):
+        super().__init__(output_dir, background_jobs_manager,
+                         pretrained_model="xlm-roberta-base",
+                         batch_size=16, learning_rate=2e-5, num_train_epochs=20)
+
+    def get_supported_languages(self):
+        """
+        While XLM-R will not support every possible language, it should be usable (to some extent) for 100 languages,
+        as specified here: https://data.statmt.org/cc-100/
+        """
+        return Languages.all_languages()
+
+
+class HFTransformers(HFBert):
+    """
+    Keep old BERT class name for backward compatibility
+    """
