@@ -23,7 +23,7 @@ import time
 from collections import Counter, defaultdict
 from concurrent.futures.thread import ThreadPoolExecutor
 from datetime import datetime
-from typing import Mapping, List, Sequence, Union, Tuple, Set
+from typing import Mapping, List, Sequence, Union, Tuple
 
 import jsonpickle
 import pandas as pd
@@ -32,8 +32,7 @@ from label_sleuth.active_learning.core.active_learning_factory import ActiveLear
 from label_sleuth.analysis_utils.labeling_reports import get_suspected_labeling_contradictions_by_distance_with_diffs, \
     get_disagreements_using_cross_validation
 from label_sleuth.config import Configuration
-from label_sleuth.data_access.core.data_structs import DisplayFields, Document, Label, TextElement, LABEL_POSITIVE, \
-    LabelType
+from label_sleuth.data_access.core.data_structs import DisplayFields, Document, Label, TextElement, LABEL_POSITIVE
 from label_sleuth.data_access.data_access_api import DataAccessApi
 from label_sleuth.data_access.label_import_utils import process_labels_dataframe
 from label_sleuth.data_access.processors.csv_processor import CsvFileProcessor
@@ -44,10 +43,11 @@ from label_sleuth.models.core.model_type import ModelType
 from label_sleuth.models.core.models_factory import ModelFactory
 from label_sleuth.models.core.prediction import Prediction
 from label_sleuth.models.core.tools import SentenceEmbeddingService
+from label_sleuth.orchestrator.background_jobs_manager import BackgroundJobsManager
 from label_sleuth.orchestrator.core.state_api.orchestrator_state_api import Category, Iteration, IterationStatus, \
     ModelInfo, OrchestratorStateApi
 from label_sleuth.orchestrator.utils import convert_text_elements_to_train_data
-from label_sleuth.training_set_selector.training_set_selector_factory import get_training_set_selector
+from label_sleuth.training_set_selector.training_set_selector_factory import TrainingSetSelectionFactory
 
 # constants
 NUMBER_OF_MODELS_TO_KEEP = 2
@@ -60,13 +60,18 @@ new_data_infer_thread_pool = ThreadPoolExecutor(1)
 class OrchestratorApi:
     def __init__(self, orchestrator_state: OrchestratorStateApi, data_access: DataAccessApi,
                  active_learning_factory: ActiveLearningFactory, model_factory: ModelFactory,
+                 training_set_selection_factory: TrainingSetSelectionFactory,
+                 background_jobs_manager: BackgroundJobsManager,
                  sentence_embedding_service: SentenceEmbeddingService, config: Configuration):
         self.orchestrator_state = orchestrator_state
         self.data_access = data_access
         self.active_learning_factory = active_learning_factory
         self.model_factory = model_factory
+        self.background_jobs_manager = background_jobs_manager
         self.sentence_embedding_service = sentence_embedding_service
+        self.training_set_selection_factory = training_set_selection_factory
         self.config = config
+        self._verify_model_and_language_compatibility()
 
     def get_all_dataset_names(self):
         return sorted(self.data_access.get_all_dataset_names())
@@ -275,8 +280,14 @@ class OrchestratorApi:
         specific situations this parameter is set to False and the updating of the counter is performed at a later time.
         """
         if update_label_counter:
+            train_set_selector = self.training_set_selection_factory.\
+                get_training_set_selector(self.config.training_set_selection_strategy)
+
+            used_label_types = train_set_selector.get_label_types()
             # count the number of labels for each category
-            changes_per_cat = Counter([cat for uri, labels_dict in uri_to_label.items() for cat in labels_dict])
+            changes_per_cat = Counter([cat for uri, labels_dict in uri_to_label.items()
+                                       for cat, cat_label in labels_dict.items()
+                                       if cat_label.label_type in used_label_types])
             for cat, num_changes in changes_per_cat.items():
                 self.orchestrator_state.increase_label_change_count_since_last_train(workspace_id, cat, num_changes)
         self.data_access.set_labels(workspace_id, uri_to_label, apply_to_duplicate_texts)
@@ -306,8 +317,8 @@ class OrchestratorApi:
         :return:
         """
         if counts_for_training:
-            train_set_selector = get_training_set_selector(self.data_access,
-                                                           strategy=self.config.training_set_selection_strategy)
+            train_set_selector = self.training_set_selection_factory.get_training_set_selector(
+                                                           self.config.training_set_selection_strategy)
             used_label_types = train_set_selector.get_label_types()
             return self.data_access.get_label_counts(workspace_id, dataset_name, category_id,
                                                      remove_duplicates=remove_duplicates,
@@ -361,7 +372,8 @@ class OrchestratorApi:
         workspace = self.orchestrator_state.get_workspace(workspace_id)
         if workspace.categories[category_id] is not None:
             for idx in range(len(workspace.categories[category_id].iterations)):
-                if workspace.categories[category_id].iterations[idx].model.model_status != ModelStatus.DELETED:
+                if workspace.categories[category_id].iterations[idx].model is not None \
+                        and workspace.categories[category_id].iterations[idx].model.model_status != ModelStatus.DELETED:
                     self.delete_iteration_model(workspace_id, category_id, idx)
 
     def get_elements_to_label(self, workspace_id: str, category_id: int, count: int, start_index: int = 0) \
@@ -385,7 +397,7 @@ class OrchestratorApi:
 
     # Iteration flow
 
-    def run_iteration(self, workspace_id: str, category_id: int, model_type: ModelType, train_data) -> str:
+    def run_iteration(self, workspace_id: str, dataset_name: str, category_id: int, model_type: ModelType):
         """
         This method initiates an Iteration, a flow that includes training a model, inferring the full corpus using
         this model, choosing candidate elements for labeling using active learning, as well as calculating various
@@ -398,13 +410,34 @@ class OrchestratorApi:
         launched when the training and inference stages, respectively, are completed.
 
         :param workspace_id:
+        :param dataset_name:
         :param category_id:
         :param model_type:
-        :param train_data:
-        :return: model_id
         """
+        new_iteration_index = len(self.orchestrator_state.get_all_iterations(workspace_id, category_id))
+        logging.info(f"starting iteration {new_iteration_index} in background for workspace '{workspace_id}' "
+                     f"category id '{category_id}'")
 
-        def _get_counts_per_label(text_elements):
+        self.orchestrator_state.add_iteration(workspace_id=workspace_id, category_id=category_id)
+        train_set_selector = self.training_set_selection_factory.get_training_set_selector(
+            self.config.training_set_selection_strategy)
+        future = train_set_selector.collect_train_set(workspace_id=workspace_id,
+                                                      train_dataset_name=dataset_name,
+                                                      category_id=category_id)
+        future.add_done_callback(functools.partial(self._train_callback, workspace_id, category_id, model_type,
+                                                   new_iteration_index))
+
+    def _train_callback(self, workspace_id, category_id, model_type, iteration_index, future):
+        try:
+            train_data = future.result()
+        except Exception:
+            logging.exception(f"Train set selection failed. Marking workspace '{workspace_id}' "
+                              f"category id '{category_id}' iteration {iteration_index} as error")
+            self.orchestrator_state.update_iteration_status(workspace_id, category_id, iteration_index,
+                                                            IterationStatus.ERROR)
+            return
+
+        def _get_counts_per_label(text_elements, category_id):
             """
             These label counts reflect the more detailed description of training labels, e.g. how many of the elements
             have weak labels
@@ -414,27 +447,26 @@ class OrchestratorApi:
 
             return dict(Counter(label_names))
 
-        new_iteration_index = len(self.orchestrator_state.get_all_iterations(workspace_id, category_id))
-        logging.info(f"starting iteration {new_iteration_index} in background for workspace '{workspace_id}' "
-                     f"category id '{category_id}' using {len(train_data)} items")
-
-        train_counts = _get_counts_per_label(train_data)
+        train_counts = _get_counts_per_label(train_data, category_id)
         train_data = convert_text_elements_to_train_data(train_data, category_id)
         train_statistics = {TRAIN_COUNTS_STR_KEY: train_counts}
+
+        self.orchestrator_state.update_iteration_status(workspace_id=workspace_id, category_id=category_id,
+                                                        iteration_index=iteration_index,
+                                                        new_status=IterationStatus.TRAINING)
         model_api = self.model_factory.get_model_api(model_type)
 
         logging.info(f"workspace '{workspace_id}' training a model for category id '{category_id}', "
                      f"train_statistics: {train_statistics}")
-
         model_id, future = model_api.train(train_data=train_data, language=self.config.language)
         model_status = model_api.get_model_status(model_id)
         model_info = ModelInfo(model_id=model_id, model_status=model_status, model_type=model_type,
                                train_statistics=train_statistics, creation_date=datetime.now())
-        self.orchestrator_state.add_iteration(workspace_id=workspace_id, category_id=category_id,
-                                              model_info=model_info)
+        self.orchestrator_state.add_model(workspace_id=workspace_id, category_id=category_id,
+                                          iteration_index=iteration_index, model_info=model_info)
         # The train callback is added here to ensure it only runs after the iteration has been added
         future.add_done_callback(functools.partial(self._train_done_callback, workspace_id, category_id,
-                                                   new_iteration_index))
+                                                   iteration_index))
         # The model id is returned almost immediately, but the training is performed in the background. Once training is
         # complete the iteration flow continues in the *_train_done_callback* method
         return model_id
@@ -446,7 +478,7 @@ class OrchestratorApi:
         :param workspace_id:
         :param category_id:
         :param iteration_index:
-        :param future: future object for the train job, which was submitted through the ModelsBackgroundJobsManager
+        :param future: future object for the train job, which was submitted through the BackgroundJobsManager
         """
         try:
             model_id = future.result()
@@ -484,7 +516,7 @@ class OrchestratorApi:
         :param workspace_id:
         :param category_id:
         :param iteration_index:
-        :param future: future object for the inference job, which was submitted through the ModelsBackgroundJobsManager
+        :param future: future object for the inference job, which was submitted through the BackgroundJobsManager
         """
         try:
             predictions = future.result()
@@ -567,7 +599,14 @@ class OrchestratorApi:
         :param count:
         :param iteration_index: iteration to use
         """
-        active_learner = self.active_learning_factory.get_active_learner(self.config.active_learning_strategy)
+
+        if self.config.active_learning_strategy is not None:
+            active_learning_strategy = self.config.active_learning_strategy
+        else:
+            active_learning_strategy = self.config.active_learning_policy.get_active_learning_strategy(iteration_index)
+
+        active_learner = self.active_learning_factory.get_active_learner(active_learning_strategy)
+        logging.info(f"using active learning {active_learner}")
         # Where labels are applied to duplicate texts (the default behavior), we do not want duplicates to appear in
         # the Label Next list
         remove_duplicates = self.config.apply_labels_to_duplicate_texts
@@ -643,20 +682,13 @@ class OrchestratorApi:
                     f"(>={self.config.changed_element_threshold}). Training a new model")
                 iteration_num = len(iterations_without_errors)
                 model_type = self.config.model_policy.get_model_type(iteration_num)
-                train_set_selector = get_training_set_selector(self.data_access,
-                                                               strategy=self.config.training_set_selection_strategy)
-                train_data = train_set_selector.get_train_set(workspace_id=workspace_id,
-                                                              train_dataset_name=dataset_name,
-                                                              category_id=category_id)
-                model_id = self.run_iteration(workspace_id=workspace_id, category_id=category_id,
-                                              model_type=model_type, train_data=train_data)
-                return model_id
+                self.run_iteration(workspace_id=workspace_id, dataset_name=dataset_name, category_id=category_id,
+                                   model_type=model_type)
             else:
                 logging.info(f"{label_counts[LABEL_POSITIVE]} positive elements "
                              f"(should be >={self.config.first_model_positive_threshold}) "
                              f"AND {changes_since_last_model} elements changed since last model "
                              f"(should be >={self.config.changed_element_threshold}). not training a new model")
-                return None
         except Exception:
             iterations_latest = self.orchestrator_state.get_all_iterations(workspace_id, category_id)
             if len(iterations) != len(iterations_latest):
@@ -670,9 +702,7 @@ class OrchestratorApi:
             else:
                 # iteration yet to be created, add and set status to error
                 iteration_index = len(iterations_latest)
-                model_info = ModelInfo(model_id="error-did_not_start", model_status=ModelStatus.ERROR,
-                                       creation_date=datetime.now(), model_type=None, train_statistics={})
-                self.orchestrator_state.add_iteration(workspace_id, category_id, model_info=model_info)
+                self.orchestrator_state.add_iteration(workspace_id, category_id)
                 self.orchestrator_state.update_iteration_status(workspace_id, category_id, iteration_index,
                                                                 IterationStatus.ERROR)
 
@@ -697,15 +727,16 @@ class OrchestratorApi:
             iteration = [it for it in iterations if it.status == IterationStatus.READY][-1]
         else:
             iteration = iterations[iteration_index]
-            if iteration.status in [IterationStatus.TRAINING, IterationStatus.MODEL_DELETED, IterationStatus.ERROR]:
+            if iteration.status in [IterationStatus.PREPARING_DATA, IterationStatus.TRAINING,
+                                    IterationStatus.MODEL_DELETED, IterationStatus.ERROR]:
                 raise Exception(
-                    f"iteration {iteration_index} in workspace '{workspace_id}' category id'{category_id}' "
+                    f"iteration {iteration_index} in workspace '{workspace_id}' category id '{category_id}' "
                     f"is not ready for inference. "
                     f"(current status is {iteration.status}, model status is {iteration.model.model_status})")
 
         model_info = iteration.model
         if model_info.model_status != ModelStatus.READY:
-            raise Exception(f"model id {model_info.model_id} is not in READY status"
+            raise Exception(f"model id {model_info.model_id} is not in READY status "
                             f"while iteration status is {iteration.status}.  Something went wrong")
 
         model_api = self.model_factory.get_model_api(model_info.model_type)
@@ -720,7 +751,7 @@ class OrchestratorApi:
         dataset_name = self.get_dataset_name(workspace_id)
         labeled_elements = self.get_all_labeled_text_elements(workspace_id, dataset_name, category_id)
         return get_suspected_labeling_contradictions_by_distance_with_diffs(
-            category_id, labeled_elements, self.sentence_embedding_service.get_glove_representation,
+            category_id, labeled_elements, self.sentence_embedding_service.get_sentence_embeddings_representation,
             language=self.config.language)
 
     def get_suspicious_elements_report(self, workspace_id, category_id,
@@ -823,13 +854,15 @@ class OrchestratorApi:
             return {"all": 0}
 
     # Import/Export
-
+    
     def import_category_labels(self, workspace_id, labels_df_to_import: pd.DataFrame):
-        logging.info(f"Importing {len(labels_df_to_import)} unique labeled elements into workspace '{workspace_id}'"
+        logging.info(f"Importing {len(labels_df_to_import)} labeled elements into workspace '{workspace_id}'"
                      f"from {len(labels_df_to_import[DisplayFields.category_name].unique())} categories")
         dataset_name = self.get_dataset_name(workspace_id)
-        imported_categories_to_uris_and_labels = process_labels_dataframe(workspace_id, dataset_name, self.data_access,
-                                                                          labels_df_to_import)
+        # Only if doc_id are provided or apply_labels_to_duplicate_texts is false the doc_id is taken into account when applying labels
+        apply_labels_to_duplicate_texts = self.config.apply_labels_to_duplicate_texts is True or not DisplayFields.doc_id in labels_df_to_import.columns
+        (imported_categories_to_uris_and_labels, contracticting_labels_info) = process_labels_dataframe(workspace_id, dataset_name, self.data_access, labels_df_to_import, apply_labels_to_duplicate_texts=apply_labels_to_duplicate_texts)
+        
         # name to id mapping for *existing* categories
         category_name_to_id = {category.name: category_id
                                for category_id, category in self.get_all_categories(workspace_id).items()}
@@ -855,7 +888,7 @@ class OrchestratorApi:
             else:
                 logging.info(f'{category_name}: adding labels for {len(uri_to_label)} uris')
                 self.set_labels(workspace_id, uri_to_label,
-                                apply_to_duplicate_texts=self.config.apply_labels_to_duplicate_texts,
+                                apply_to_duplicate_texts=False,
                                 update_label_counter=True)
 
             label_counts_dict = self.get_label_counts(workspace_id, dataset_name, category_id, remove_duplicates=False)
@@ -865,11 +898,12 @@ class OrchestratorApi:
         # TODO return both positive and negative counts
         categories_counter_list = [{'category_id': key, 'counter': value} for key, value in categories_counter.items()]
         total = sum(categories_counter.values())
-
+        
         res = {'categories': categories_counter_list,
                'categoriesCreated': categories_created,
                'linesSkipped': lines_skipped,
-               'total': total}
+               'total': total,
+               'contracticting_labels_info': contracticting_labels_info}
         return res
 
     def export_workspace_labels(self, workspace_id, labeled_only) -> pd.DataFrame:
@@ -897,8 +931,8 @@ class OrchestratorApi:
                 text_elements = self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category_id,
                                                                            remove_duplicates=False)['results']
             else:
-                train_set_selector = get_training_set_selector(self.data_access,
-                                                               strategy=self.config.training_set_selection_strategy)
+                train_set_selector = self.training_set_selection_factory.get_training_set_selector(
+                    self.config.training_set_selection_strategy)
                 text_elements = train_set_selector.get_train_set(workspace_id=workspace_id,
                                                                  train_dataset_name=dataset_name,
                                                                  category_id=category_id)
@@ -1007,3 +1041,14 @@ class OrchestratorApi:
         """
         dataset_name = self.get_dataset_name(workspace_id)
         return self.data_access.preload_dataset(dataset_name)
+
+    def _verify_model_and_language_compatibility(self):
+        """
+        Check that the model policy is compatible with the system language configuration
+        """
+        model_policy = self.config.model_policy
+        for model_type in model_policy.get_all_model_types():
+            model_supported_languages = self.model_factory.get_model_api(model_type).get_supported_languages()
+            if self.config.language not in model_supported_languages:
+                raise Exception(f"{self.config.language.name} is not supported by the model {model_type.name}, "
+                                f"which is used by the configured model policy {model_policy.get_name()}")
